//
//  FanBookApi.h
//  MSLDFanBookPackage
//
//  Created by berton.luo on 2021/3/1.
//

#import <Foundation/Foundation.h>
#import <FanBookSDK/FanBookApiObject.h>

NS_ASSUME_NONNULL_BEGIN

@interface FanBookApi : NSObject

/// FanBook SDK 注册
/// @param clientId FanBook应用 clientId
/// @return 成功返回YES，失败返回NO
+ (BOOL)registerApp:(NSString *)clientId;

/// 检查FanBook是否已被用户安装
/// @return 已安装返回YES，未安装返回NO。
+ (BOOL)isFanBookAppInstalled;

/// 获取当前FanBook SDK的版本号
/// @return 返回当前FanBook SDK的版本号
+ (NSString *)getSDKVersion;

/// 打开一个链接
/// @param url url地址
+ (void)openUrl:(NSString *)url;

/// 打开FanBook APP
/// @args 包含邀请链接以及参数 @{"url":"https://fanbook.mobi/xxxxxxx"}
/// @completion 回调
+ (void)openFanBookApp:(nullable NSDictionary *)args completion:(void (^__nullable)(BOOL success))completion;

/// @打开圈子接口已废弃
/// 打开FanBook圈子
/// @param serviceID 圈子的服务器ID
/// @param channelID 圈子ID
+ (BOOL)openFanBookZoneWithServiceID:(NSString *)serviceID channelID:(NSString *)channelID;

/// 发送请求到FanBook，等待FanBook返回onResp
/// 函数调用成功后，会跳转到FanBook的界面。支持以下类型 FanBookSendAuthReq,FanbookShareImageReq,FanbookShareLinkReq等。
/// @param req 具体的发送请求
/// @param succ 发送请求成功
/// @param fail 发送请求失败
+ (void)sendReq:(FanBookBaseReq *)req success:(FanBookSDKSuccess)succ fail:(FanBookSDKFail)fail;

/// 处理FanBook APP通过URL启动接入方应用时传递的数据
/// 需要在 application:openURL:sourceApplication:annotation:或者application:handleOpenURL中调用，只有在调用该方法后，才会收到onResp代理方法。
/// @param url FanBook启动接入方应用时传递过来的URL
/// @param delegate FanBookApiDelegate对象，用来接收FanBook触发的消息
/// @return 成功返回YES，失败返回NO。
+ (BOOL)handleOpenURL:(NSURL *)url delegate:(nullable id<FanBookApiDelegate>)delegate;

@end

NS_ASSUME_NONNULL_END
